/*
 * This file is part of JPuzzle.
 *
 * JPuzzle is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JPuzzle is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JPuzzle.  If not, see <http://www.gnu.org/licenses/>.
 *
 * JPuzzle Copyright © 2008 HackmanGT
 * HackmanGT@hotmail.com
 */

package JPuzzle.Graphics;

import java.awt.image.BufferedImage;
import java.io.IOException;
import javax.imageio.ImageIO;

/**
 * La matriz se encarga de cargar una imagen almacenada en el jar, y devolver
 * diferentes piezas dependiendo de la celda.
 * @author HackmanGT
 */
public class Matriz {

    private BufferedImage bi = null;

    /**
     * Intenta cargar una imagen del archivo de recursos.
     * @throws java.io.IOException si ocurrió un error al cargar la imagen
     */
    public void loadImage() throws IOException {
        int r = (int) (Math.random() * 3) + 1;
        bi = ImageIO.read(getClass().getResource(
                "/JPuzzle/Graphics/JPuzzle" + r + ".gif"));
    }

    /**
     * Devuelve una pieza de la imagen en función de los parámetros.
     * @param x la posición horizontal en coordenadas del tablero
     * @param y la posición vertical en coordenadas del tablero
     * @param w el ancho en coordenadas del tablero
     * @param h el alto en coordenadas del tablero
     * @return una pieza de la imagen original
     */
    public BufferedImage getTile(int x, int y, int w, int h) {
        if (bi != null) {
            int cellWidth = bi.getWidth(null) / w;
            int cellHeight = bi.getHeight(null) / h;
            return bi.getSubimage(
                    x * cellWidth,
                    y * cellHeight,
                    cellWidth,
                    cellHeight);
        }
        return null;
    }
}
