/*
 * This file is part of JPuzzle.
 *
 * JPuzzle is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * JPuzzle is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JPuzzle.  If not, see <http://www.gnu.org/licenses/>.
 *
 * JPuzzle Copyright © 2008 HackmanGT
 * HackmanGT@hotmail.com
 */

package JPuzzle.Utilities;

/**
 * La tabla es el modelo abstracto para guardar todas las celdas que componen
 * el juego, así como almacenar el ancho y el alto, y obtener sus dimensiones.
 * @author HackmanGT
 */
public abstract class Tabla {

    /**
     * El ancho de la tabla.
     */
    protected int ancho = 0;
    /**
     * El alto de la tabla.
     */
    protected int alto = 0;
    /**
     * Las celdas que componen la tabla.
     */
    protected Celda[][] celdas;

    /**
     * Valida que la posición indicada se encuentre en el rango válido, dentro
     * de los límites de la tabla.
     * @param p la posición a validar
     * @return verdadero si la posición esta en el rango, sino falso
     */
    protected boolean esPosicionValida(Posicion p) {
        return
                p.getX() >= 0 &&
                p.getX() < ancho &&
                p.getY() >= 0 &&
                p.getY() < alto;
    }

    /**
     * Obtiene una celda indicada por los ejes x, y; no revisa que sea válida,
     * usar con cuidado (preferiblemente llamar esPosicionValida()). Esta
     * función se puede llegar a ejecutar más de 280,000 veces al resolver.
     * @param x la posición en el eje x
     * @param y la posición en el eje y
     * @return la celda que representa las coordenadas indicadas
     */
    public Celda getCelda(int x, int y) {
        // if (esPosicionValida(new Posicion(x, y))) {
        //    return celdas[x][y];
        // }
        // return null;
        return celdas[x][y];
    }

    /**
     * Devuelve el tamaño de la tabla, el ancho multiplicado por el alto.
     * @return el tamaño de la tabla
     */
    public int getTamano() {
        return ancho * alto;
    }

    /**
     * Devuelve el ancho de la tabla.
     * @return el ancho de la tabla
     */
    public int getAncho() {
        return ancho;
    }

    /**
     * Asigna un valor al ancho de la tabla.
     * @param ancho el ancho de la tabla
     */
    protected void setAncho(int ancho) {
        this.ancho = ancho;
    }

    /**
     * Devuelve el alto de la tabla.
     * @return el alto de la tabla
     */
    public int getAlto() {
        return alto;
    }

    /**
     * Asigna un valor al alto de la tabla.
     * @param alto el alto de la tabla
     */
    protected void setAlto(int alto) {
        this.alto = alto;
    }
}
